/////////////////////////////////////////////////////////////
// PlayerSave
/////////////////////////////////////////////////////////////
// Author: Ebonshadow
// Email: Ebonshadow@TeamEbon.com
// Last Updated: 05/30/03
/////////////////////////////////////////////////////////////
// This library is used to create a start screen for your MUD
// as well as create a player saving system.  Players will be
// saved when they logout or whenever mob.mb_Save() is called.
// You can use mb_Save() to save and mb_Load() to load.  The
// startup screen is stored in MOTD.txt, so just edit that
// to change the startup.  If you want other stuff to happen
// after the user logs in, override this proc: mob.mb_loggedin()
// After a player first creates his character,
// mob.mb_createcharacter() is called.  Override this proc
// with your character creation code.
/////////////////////////////////////////////////////////////
// mob.mb_Save()
//		Saves the mob.
// mb_Load(name)
//		Loads the mob from name.
//		returns the loaded mob.
// mob.mb_loggedin()
//		This proc gets called after the player logs in.
//		Override this.
// mob.mb_createcharacter()
//		This gets called after a player chooses a password
//		for his character.  Override this.
// mob.mb_checkname(name)
//		Default:  return 1
//		This proc is called when a name is being chosen for a new character.  You
//		can override this to prevent the player from choosing certain names.  IE:
//			mob/mb_checkname(name)
//				if(length(name) < 5)
//					mb_msgout("Too short!", src)
//					return 0
//				return 1
//		That would force names to be 5 characters or more.
/////////////////////////////////////////////////////////////
// Lots of definitions make it easy to customize this
// exactly the way you want.
/////////////////////////////////////////////////////////////
#define	MOTD_FILE		"MOTD.txt"
#define	GET_NAME		"What is your name?"
#define CONFIRM_NAME	"Is \"[new_name]\" really your character's name?"
#define REGET_NAME		"Then what is your name?"
#define	CHOOSE_PASSWORD	"You must choose a password.\nYour password must be at least 5 characters long."
#define	PASSWORD1		"Password:"
#define	PASSWORD2		"Password: (again)"
#define	PASSWORD_ERROR	"Passwords don't match!"
#define	PASSWORD_LOGIN	"Password:"
#define	LOGIN_ERROR		"Incorrect password!"
#define	WELCOME_BACK	"Welcome back!"
#define	FIRST_WELCOME	"Welcome newcomer!"
#define PASSWORD_SHORT	"Your password must be at least 5 characters long."
#define PASSWORD_LENGTH	5
#define PLAYER_DIR		"Players"

// Also, remember if you have the escape library installed, you
// can use your escapes in MOTD.txt

var/MOTD= mb_align(file2text(MOTD_FILE))

client/New()
	. = ..()
	mb_ChooseCharacter()
	return ..()
client/proc/mb_ChooseCharacter()
	var/nameq = GET_NAME
	var/new_name = ""
	mb_msgout(MOTD,src)
	reget_name:
	while(!new_name)
		new_name = mb_input_text(nameq,src)
		if(!mob.mb_checkname(new_name)) new_name = null
	var/mob/newmob = mb_Load(new_name)
	if(!newmob.password)
		var/n = "[uppertext(copytext(new_name,1,2))][lowertext(copytext(new_name,2))]"
		new_name = n
		var/confirm = mb_input_confirm(CONFIRM_NAME,src)
		if(!confirm)
			nameq = REGET_NAME
			new_name = null
			goto reget_name

		mb_msgout(CHOOSE_PASSWORD,src)
		newmob.name = new_name
		var/pass1
		var/pass2
		while(1)
			pass1 = GetPassword(PASSWORD1,src)
			pass2 = GetPassword(PASSWORD2,src)
			if(pass1==pass2) break
			else mb_msgout(PASSWORD_ERROR,src)
		newmob.password = pass1
		mb_msgout(FIRST_WELCOME,src)
		mob = newmob
		newmob.mb_Save()
		newmob.mb_createcharacter()
	else
		var/pass = mb_input_text(PASSWORD_LOGIN,src)
		if(pass!=newmob.password)
			mb_msgout(LOGIN_ERROR,src)
			del(src)
		mb_msgout(WELCOME_BACK,src)
		mob=newmob
	mob.mb_loggedin()
	return ..()

mob/proc/mb_loggedin()
mob/proc/mb_createcharacter()
mob/proc/mb_checkname(name) return 1

proc/GetPassword(prompt,m=usr)
	usr= m
	var/password
	while(!password)
		password = mb_input_text(prompt)
		if(length(password)<PASSWORD_LENGTH)
			mb_msgout(PASSWORD_SHORT)
			password= null
	return password
mob
	var
		password
	proc
		mb_Save()
			var/g = lowertext(copytext(name,1,2))
			var/dirname = ckey(name)
			var/savefile/f = new("[PLAYER_DIR]/[g]/[dirname].dat")
			f << src

proc/mb_Load(new_name)
	var/mob/m
	var/g = lowertext(copytext(new_name,1,2))
	var/dirname = ckey(new_name)
	if(!fexists("[PLAYER_DIR]/[g]/[dirname].dat")) return new /mob
	var/savefile/f = new("[PLAYER_DIR]/[g]/[dirname].dat")
	f >> m
	return m
client/Del()
	mob.mb_Save()
	del(mob)
	return ..()
proc/mb_align(text)
	text= "<pre>[text]</pre>"
	return text
